@@ -1,4 +1,5 @@
 from __future__ import annotations
+from typing import Optional
 from pydantic import BaseModel
 from .PriceModel import Price
 
@@ -10,7 +11,7 @@ class ShippingProfileDestination(BaseModel):
     destination_region: str
     primary_cost: Price
     secondary_cost: Price
-    shipping_carrier_id: int
-    mail_class: str
-    min_delivery_days: int
-    max_delivery_days: int
\ No newline at end of file
+    shipping_carrier_id: Optional[int]
+    mail_class: Optional[str]
+    min_delivery_days: Optional[int]
+    max_delivery_days: Optional[int]
\ No newline at end of file
