@@ -1,10 +1,10 @@
 from .ListingImageModel import ListingImage
-from .ListingModel import Listing
+from .ListingModel import Listing, DraftListing, VariationImage, Video
 from .ProductionPartnerModel import ProductionPartner
 from .ShippingProfileModel import ShippingProfile
 from .ShopModel import Shop
 from .TranslationModel import Translation
-from .UserModel import User
+from .UserModel import User, Me
 from .PriceModel import Price
 from .ProductModel import Product
 from .ReceiptModel import Receipt, ReceiptStatus, ReceiptType
@@ -18,4 +18,10 @@ from .VariationModel import Variation
 from .ShippingProfileUpgradeModel import ShippingProfileUpgrade
 from .RefundModel import Refund
 from .ListingModel import Inventory
-from .ListingPropertyModel import ListingProperty
\ No newline at end of file
+from .ListingPropertyModel import ListingProperty
+from .File import File
+from .ShopSection import ShopSection
+from .ReturnPolicyModel import ReturnPolicy
+from .TaxonomyModel import Taxonomy, ProductProperty
+from .ShippingCarrierModel import ShippingCarrier
+from .PaymentModel import Payment, PaymentAccountLedgerEntry
\ No newline at end of file
