@@ -35,6 +35,17 @@ class PaymentResource:
         return PaymentAccountLedgerEntry(**response)
     
     def get_shop_payment_account_ledger_entries(self, shop_id: int, min_created: int, max_created: int, limit: int = 25, offset: int = 0) -> Response[PaymentAccountLedgerEntry]:
+        """_summary_
+
+        Args:
+            shop_id (int): Target Shop ID
+            min_created (int): The earliest unix timestamp for when a record was created. 
+            max_created (int): The latest unix timestamp for when a record was created.
+            limit (int, optional): The maximum number of results to return. Defaults to 25.
+            offset (int, optional): The number of records to skip before selecting the first result. Defaults to 0.
+        Returns:
+            Response[PaymentAccountLedgerEntry]: Response Object By PaymentAccountLedgerEntry
+        """
         endpoint = f"shops/{shop_id}/payment-account/ledger-entries"
         response = self.session.request(endpoint)
         return Response[PaymentAccountLedgerEntry](**response)
