@@ -54,10 +54,33 @@ class ReceiptResource:
 
     async def aget_receipt_by_id(self, shop_id: int, receipt_id: int) -> Receipt:
         endpoint = f"shops/{shop_id}/receipts/{receipt_id}"
-        task = asyncio.create_task(self.session.async_request(endpoint=endpoint))
-        json = await asyncio.gather(task)
+        json = await self.session.async_request(endpoint)
         return Receipt(**json)
     
+    async def aget_receipts(self, shop_id: int, limit: int = 25, offset: int = 0, type: ReceiptType = ReceiptType.UNSHIPPED, **kwargs):
+        """
+        Get Shop Receipts By Shop ID And Receipt Type
+
+        Args:
+            
+            shop_id (int): Your SHOP ID
+            limit (int, optional): Limit Of Receipt Objects. Defaults to 25.
+            offset (int, optional): How many receipts to skip. Defaults to 0.
+            type (ReceiptType, optional): Receipt type to find. Defaults to ReceiptType.UNSHIPPED.
+
+        Returns:
+            Response[Receipt]: Create Response Object Derived from the Receipt Object from json
+        """
+        
+        endpoint = f"shops/{shop_id}/receipts"
+        
+        params = {"limit": limit, "offset": offset}
+        params.update(type)
+        params.update(kwargs)
+        json = await self.session.async_request(endpoint=endpoint, params=params)
+        
+        return Response[Receipt](**json)
+    
     def create_shipment(self, shop_id: int, receipt_id: int, tracking_number: str, carrier_name: str, send_bcc: bool = True, note_to_buyer: str = "") -> Receipt:
         """
         Adds tracking information to the receipt object
