@@ -26,7 +26,7 @@ class ShopResource:
         response = self.session.request(endpoint)
         return Shop(**response)
     
-    def find_shops(self, shop_name: str):
+    def find_shops(self, shop_name: str, limit: int = 25, offset: int = 0):
         """
         Find All Shops And Return Response Object
         
@@ -34,7 +34,7 @@ class ShopResource:
             Response: Return Response object of shop list 
         """
         endpoint = "shops"
-        response = self.session.request(endpoint, params={"shop_name":shop_name})
+        response = self.session.request(endpoint, params={"shop_name":shop_name, "limit": limit, "offset": offset})
         return Response[Shop](**response)
 
     def get_shop_by_owner_user_id(self, user_id: int):
