@@ -54,7 +54,7 @@ class EtsySession:
                                 )
         return session
     
-    def __create_async_oauth2_session(self) -> AsyncOAuth2Session:
+    def create_async_oauth2_session(self) -> AsyncOAuth2Session:
         refresh_kwargs = {
         'client_id': self.CLIENT_KEY,
         'client_secret': self.CLIENT_SECRET,
@@ -105,24 +105,12 @@ class EtsySession:
     async def async_request(self, endpoint: str,  session: AsyncOAuth2Session = None, method="GET", headers: Optional[dict] = None, *args, **kwargs) -> dict:
         
         url = f"{self.__base_endpoint}{endpoint}"
+        
         if headers is None:
             headers = {"x-api-key": self.CLIENT_KEY}
         
-        if session is None:
-            session = self.__create_async_oauth2_session()
-        
-        async with session as s:
-            while True:
-                
-                res = await s.get(url=url, headers=headers, *args, **kwargs)
-        
-                json = await res.json()
-                if "error" in json.keys():
-                    if res.status == 429:
-                        await asyncio.sleep(0.5)
-                    else:
-                        raise EtsyRequestException(res.status, json["error"])
-                else:
-                    break
-                
-            return json
+        res = await session.get(url=url, headers=headers, *args, **kwargs)
+        json = await res.json()
+        if "error" in json.keys():
+            raise EtsyRequestException(res.status, json["error"])
+        return json
